@@ -16,8 +16,11 @@
 ;;; along with this program; if not, write to the Free Software
 ;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
 
-(define (receive-beep timestamp from msg)
-  "beep on receiving message"
-  (system "beep -f 600 -l 10; beep -f 800 -l 10; beep -f 200 -l 10&"))
+(if (= (system "beep -f 1 -l 0 >> /dev/null 2>&1") 0)
+    (add-hook! ft-message-receive-hook 
+	       (lambda (time from nickname message)
+		 (system "beep -f 600 -l 10; beep -f 800 -l 10; beep -f 200 -l 10&")))
+    (add-hook! ft-message-receive-hook 
+	       (lambda (time from nickname message)
+		 (ft-beep 200 20))))
 
-(add-hook! ft-message-receive-hook receive-beep)
