@@ -38,19 +38,13 @@
 		       command)))
 
 (define (dynamic-command-proc command args)
-  (if (not args)
-      (set! args ""))
   ((lambda (cmd-entry)
      (if cmd-entry
-	(begin
-	  ((car cmd-entry) args)
-	  (ft-hook-return)))) (assoc-ref dynamic-command-registry command)))
-      ;;  (if (string-null? args)
-      ;;	  (ft-hook-return))
-       ;; Terminate all empty messages here - AVATI: moved to commands.c:do_send_message()
-
+        (begin
+          ((car cmd-entry) args)
+          (ft-hook-return)))) (assoc-ref dynamic-command-registry command)))
 (add-hook! ft-command-hook dynamic-command-proc)
-
+	
 (define (help args)
   "display help message"
   (let ((command-name (sans-surrounding-whitespace args))
