@@ -18,12 +18,11 @@
 ;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
 
 ;;; shell command for pagination
-(define history-page-cmd "less --quit-at-eof --quit-if-one-screen ")
+(define history-page-cmd "less --quit-at-eof ")
 
 ;;; history path
-(define history-path "HISTORY PATH WILL BE SET IN POST-STARTUP")
-(define session-file "SESSION FILE NAME WILL BE SET IN POST-STARTUP")
-
+(define history-path "/dev/")
+(define session-file "/dev/null")
 
 ;;; append this message to session history file with time stamp
 (define (history-raw-session message)
@@ -72,7 +71,7 @@
 	   message))
 
 ;;; hook procedure for logging all revceived messages
-(define (log-received-message time from message)
+(define (log-received-message time from nickname message)
   "hook procedure for logging all revceived messages" 
   (history (string-append history-path "/" from)
 	   from
@@ -96,15 +95,18 @@
 		      "/history/"
 		      (ft-get-jid)))
     (set! session-file (string-append history-path "/SESSION"))
-    (history-create-dirs)
-    ;; Truncate SESSION file upon successful login
-    (close-port (open-output-file session-file)))))
+    (history-create-dirs))))
+
+(define (post-disconnect reason)
+  (and (= reason 0)
+       (close-port (open-output-file session-file))))
 
 ;;; hook the logging procedures to send and reveice hooks
 (add-hook! ft-message-send-hook log-sent-message)
 (add-hook! ft-message-receive-hook log-received-message)
 ;(add-hook! fh-message-receive-offline-hook log-received-offline-message)
 (add-hook! ft-login-hook post-startup)
+(add-hook! ft-disconnect-hook post-disconnect)
 
 (define (/history args)
   "less on history session"
