@@ -1,5 +1,5 @@
 ;;; init.scm: startup extension
-;;; author: Anand Babu <ab@gnu.org.in>
+;;; author: Anand Babu <ab@zresearch.com>
 ;;; copyright 2005 FreeTalk Core Team
 
 ;;; This program is free software; you can redistribute it and/or
@@ -17,8 +17,21 @@
 ;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
 
 (use-modules (ice-9 debugger))
+(use-modules (ice-9 format))
 (debug-enable 'backtrace)
 
+(if (defined? 'gettext)
+    (begin
+      (catch #t
+	     (lambda ()
+	       (setlocale LC_ALL=""))
+	     (lambda args #f))
+      (textdomain "freetalk")
+      (bindtextdomain "freetalk" "/usr/share/locale")
+      (define _ gettext))
+    (begin
+      (define _ (lambda (text) text))))
+
 (catch #t
        (lambda ()
 	 ;; IMPORTANT: ORDER OF LOADING EXETNSIONS IS DEPENDENT ON THE
@@ -26,12 +39,15 @@
 
 	 ; (ft-load "pre-login-extensions-here.scm")
 	 (ft-load "dyn-commands.scm")
+	 (ft-load "loudscream.scm")
 
 	 (if (= (system "dict gnu >> /dev/null 2>&1") 0)
 	     (ft-load "dict-buddy.scm"))
-	 (if (= (system "beep -f 1 -l 0 >> /dev/null 2>&1") 0)
-	     (ft-load "beep.scm"))
 
+	 (if (= (system "which urlview >>/dev/null 2>&1") 0)
+	     (ft-load "url.scm"))
+	 
+	 (ft-load "beep.scm")
 	 (ft-load "utils.scm")
 	 (ft-load "mr-oxford.scm") 
 	 (ft-load "shell.scm")
@@ -40,7 +56,12 @@
 	 (ft-load "connection.scm")
 	 (ft-load "roster.scm")
 	 (ft-load "color.scm")
-     (ft-load "history.scm")
+	 (ft-load "history.scm")
+	 (ft-load "proud-of-freetalk.scm")
+	 (ft-load "file-transfer.scm")
+	 (ft-load "broadcast.scm")
+	 (ft-load "hacker-romance.scm")
+
  ;; FIXME: login.scm should not be loaded when run in script mode.
 ;	 (ft-load "login.scm")
        ; (ft-load "post-login-extensions-here.scm")
