@@ -28,7 +28,7 @@
 
 (define (/status args)
   (usual-crap ft-get-status-msg ft-set-status-msg! "Current status: " args))
-(add-command! /status "/status" "/status [NEWSTATUS]" "set status message")
+(add-command! /status "/status" "/status [online|away|chat|xa|dnd] [MESSAGE]" "set status message")
 
 (define (/server args)
   (usual-crap ft-get-server ft-set-server! "Current server: " args))
@@ -51,7 +51,9 @@
 (add-command! /port "/port" "/port [PORT]" "set server port for next /connect")
 
 (add-command! (lambda (str) 
-		(ft-load (sans-surrounding-whitespace str))) 
+		(if (> (string-length str) 0)
+		     (ft-load (sans-surrounding-whitespace str))
+		     (ft-display (_ "usage: /load [FILE]"))))
 	      "/load" "/load [FILE]" "load an extension file")
 
 (add-command! (lambda (args) (ft-reset-fs-state!)) "/setup" "/setup" "Write fresh ~/.freetalk")
