@@ -197,11 +197,11 @@ int ft_msg_sub_type_set_cb(LmMessage *msg)
 
       /* now, we'll stop here... we'll continue with file transfer only after
        * user accepts the offer with /allow-file */
-      scm_run_hook (ex_notify_file_hook, gh_list (gh_str02scm (from),
-						  gh_str02scm (file->remote_file),
-						  gh_int2scm (FT_FILE_SUCCESS),
-						  gh_int2scm (file->cookie),
-						  SCM_UNDEFINED));
+      scm_run_hook (ex_notify_file_hook, scm_list_n (scm_from_locale_string (from),
+						     scm_from_locale_string (file->remote_file),
+						     scm_from_int (FT_FILE_SUCCESS),
+						     scm_from_int (file->cookie),
+						     SCM_UNDEFINED));
     }
     state.f_state = g_slist_append (state.f_state, file);
   } else {
@@ -220,11 +220,11 @@ int ft_msg_sub_type_set_cb(LmMessage *msg)
       
       /* Before sending the 'result' reply, open the file to write to */
       if ((file->fd = open (file->local_file, O_CREAT | O_WRONLY)) < 0){
-	scm_run_hook (ex_notify_file_hook, gh_list (gh_str02scm (file->sender),
-						    gh_str02scm (file->local_file),
-						    gh_int2scm (FT_FILE_NO_OPEN),
-						    gh_int2scm (file->cookie),
-						    SCM_UNDEFINED));
+	scm_run_hook (ex_notify_file_hook, scm_list_n (scm_from_locale_string (file->sender),
+						       scm_from_locale_string (file->local_file),
+						       scm_from_int (FT_FILE_NO_OPEN),
+						       scm_from_int (file->cookie),
+						       SCM_UNDEFINED));
 	/* send an 'error' message to the sender */
 	state.f_state = g_slist_remove (state.f_state, file);
 	if (file)
@@ -562,6 +562,7 @@ static int ft_send_file_init(char *reciever, char *file)
   
   child_node = lm_message_node_add_child (msg->node, "si", NULL);
   lm_message_node_set_attributes (child_node,
+                  "xmlns", "http://jabber.org/protocol/si",
 				  "id", "a0",
 				  "mime-type", "text/plain",
 				  "profile", "http://jabber.org/protocol/si/profile/file-transfer",
@@ -623,11 +624,11 @@ int ft_send_file(char *jid_str, char *reciever, char *file_name)
 {
   
   if (ft_send_sdisco (reciever) < 0){
-    scm_run_hook (ex_notify_file_hook, gh_list (gh_str02scm (reciever),
-						gh_str02scm (file_name),
-						gh_int2scm (FT_FILE_NO_FEATURE),
-						gh_int2scm (-1),
-						SCM_UNDEFINED));
+    scm_run_hook (ex_notify_file_hook, scm_list_n (scm_from_locale_string (reciever),
+						   scm_from_locale_string (file_name),
+						   scm_from_int (FT_FILE_NO_FEATURE),
+						   scm_from_int (-1),
+						   SCM_UNDEFINED));
     return -2;
   }
 
