@@ -23,6 +23,7 @@
 
 #include <libintl.h>
 #include <loudmouth/loudmouth.h>
+#include <time.h>
 #include "util.h"
 #include "file_transfer.h"
 
@@ -62,10 +63,15 @@ typedef struct {
   char *config_dir;
   GSList *f_state; /* file transfer states - linked list */
   char *download_dirname; /* default directory where all files xfered go */
+  time_t last;
 } ft_state;
 
 extern ft_state state;
 
 void interface_init (void);
+int ft_msg_iq_version_cb (LmMessage*);
+int ft_msg_iq_last_cb (LmMessage*);
+void ft_bind_key (char key, char *command);
+void ft_bind_to_ctrl_key (char key, char *command);
 
 #endif /* __FREETALK_H__ */
